@@ -1,7 +1,7 @@
 from scale_lidar_io import *
 from .scene import DebugLidarScene as LidarScene
+from .lidarLiteHelper import get_points, get_cameras, combine_scenes
 
 
 def import_test():
-    import pptk
     print('Import OK')
